MarkdownListStyle class

A style configuration class for customizing the appearance of Markdown list items.

Constructors

MarkdownListStyle({double indent = 4, TextStyle? textStyle, String bullet = '•', TextStyle? bulletStyle, EdgeInsets bulletPadding = const EdgeInsets.only(right: 8), TextStyle? numberStyle, EdgeInsets numberPadding = const EdgeInsets.only(right: 4), bool shrinkWrap = false})
Creates a MarkdownListStyle with the specified properties.
const

Properties

bullet String
The bullet character for unordered lists.
final
bulletPadding EdgeInsets
The padding applied to the bullet in unordered lists.
final
bulletStyle TextStyle?
The text style for the bullet in unordered lists.
final
hashCode int
The hash code for this object.
no setteroverride
indent double
The indentation for list items.
final
numberPadding EdgeInsets
The padding applied to the number in ordered lists.
final
numberStyle TextStyle?
The text style for the number in ordered lists.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shrinkWrap bool
Whether the list should shrink wrap its content (affects ordered list).
final
textStyle TextStyle?
The text style for list items.
final

Methods

merge(MarkdownListStyle? other) MarkdownListStyle
Merges this MarkdownListStyle with another one.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override