markdown_rich_text library
Classes
- AlertBlockSyntax
- Parses GitHub Alerts blocks.
- AutolinkExtensionSyntax
-
Matches autolinks like
http://foo.comandfoo@bar.com. - BlockSyntax
- ColorSwatchSyntax
- Matches code blocks containing a subset of CSS color syntax.
- EmojiSyntax
-
Matches GitHub Markdown emoji syntax like
:smile:. - ExtensionSet
- ExtensionSets provide a simple grouping mechanism for common Markdown flavors.
- FencedCodeBlockSyntax
- Parses preformatted code blocks between two ~~~ or ``` sequences.
- FootnoteDefSyntax
-
The spec of GFM about footnotes is missing.
For online source code of cmark-gfm, see master@c32ef78.
A Rust implementation is also available.
Footnote definition could contain multiple line-children and children could
be separated by one empty line.
Its first child-line would be the remaining part of the first line after
taking definition leading, combining with other child lines parsed by
parseChildLines, is fed into
BlockParser. - HeaderWithIdSyntax
- Parses atx-style headers, and adds generated IDs to the generated elements.
- InlineHtmlSyntax
- Leave inline HTML tags alone, from CommonMark 0.30.
- InlineSyntax
- Represents one kind of Markdown tag that can be parsed.
- MarkdownBlockquoteStyle
- Defines the style properties for blockquote elements in Markdown rendering.
- MarkdownCodeBlockStyle
- Defines the style for code blocks in Markdown rendering.
- MarkdownHorizontalRuleStyle
- Defines the style for a horizontal rule in Markdown rendering.
- MarkdownImageConfig
- Holds configuration data for an image in a Markdown document.
- MarkdownImageStyle
- Defines the style for images in a Markdown document.
- MarkdownListStyle
- A style configuration class for customizing the appearance of Markdown list items.
- MarkdownRichText
- A widget that renders a MarkdownTextSpan as rich text with optional styling and interaction.
- MarkdownSettings
- MarkdownStyleSheet
- A class that defines the styles used for rendering Markdown elements.
- MarkdownTableStyle
- MarkdownTextSpan
- A specialized TextSpan for use with Markdown rendering.
- OrderedListWithCheckboxSyntax
- Parses ordered lists with checkboxes.
- SetextHeaderWithIdSyntax
- Parses setext-style headers, and adds generated IDs to the generated elements.
- SpacerTextSpan
- A TextSpan that acts as a spacer in the Markdown rendering process.
- StrikethroughSyntax
- Matches strikethrough syntax according to the GFM spec.
- TableSyntax
- Parses tables.
- UnorderedListWithCheckboxSyntax
- Parses unordered lists with checkboxes.